PayResult class
Constructors
- PayResult({String? trackingId, String? paymentId, String? desc, String? merchantTransactionId, String? status, String? checksum, String? descriptor, String? token, String? registrationId, String? firstName, String? lastName, String? currency, String? amount, String? tmplCurrency, String? tmplAmount, String? timestamp, String? resultCode, String? resultDescription, String? cardBin, String? cardLast4Digits, String? custEmail, String? paymentMode, String? paymentBrand})
-
PayResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- amount → String?
-
final
- cardBin → String?
-
final
- cardLast4Digits → String?
-
final
- checksum → String?
-
final
- currency → String?
-
final
- custEmail → String?
-
final
- desc → String?
-
final
- descriptor → String?
-
final
- firstName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastName → String?
-
final
- merchantTransactionId → String?
-
final
- paymentBrand → String?
-
final
- paymentId → String?
-
final
- paymentMode → String?
-
final
- registrationId → String?
-
final
- resultCode → String?
-
final
- resultDescription → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
final
- timestamp → String?
-
final
- tmplAmount → String?
-
final
- tmplCurrency → String?
-
final
- token → String?
-
final
- trackingId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited