PaymentUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildPaymentParameters(
{required PayRequest request, required String merchantRedirectUrl}) → Map< String, String> -
generateChecksum(
{required String memberId, required String toType, required String amount, required String merchantTransactionId, required String merchantRedirectUrl, required String memberKey}) → String -
generateMD5(
String input) → String -
getDeviceType(
) → String -
getHostname(
String url) → String